pub struct LightArgs {Show 27 fields
pub openmw_cfg: Option<PathBuf>,
pub use_classic: bool,
pub output: Option<PathBuf>,
pub auto_enable: bool,
pub no_notifications: bool,
pub debug: bool,
pub dry_run: Option<bool>,
pub validate_config: Option<bool>,
pub generate_completion: Option<Shell>,
pub generate_manpage: bool,
pub disable_flickering: Option<bool>,
pub disable_pulse: Option<bool>,
pub disable_negative_lights: Option<bool>,
pub standard_hue: Option<f32>,
pub standard_saturation: Option<f32>,
pub standard_value: Option<f32>,
pub standard_radius: Option<f32>,
pub colored_hue: Option<f32>,
pub colored_saturation: Option<f32>,
pub colored_value: Option<f32>,
pub colored_radius: Option<f32>,
pub duration_mult: Option<f32>,
pub excluded_ids: Vec<String>,
pub excluded_plugins: Vec<String>,
pub light_overrides: Vec<(String, CustomLightData)>,
pub ambient_overrides: Vec<(String, CustomCellAmbient)>,
pub update_light_config: bool,
}Fields
openmw_cfg: Option<PathBuf>Path to openmw.cfg By default, uses the system paths defined by: https://openmw.readthedocs.io/en/latest/reference/modding/paths.html Can be the literal path to an openmw.cfg file (including not literally being called openmw.cfg) Or the directory in which an openmw.cfg file lives.
use_classic: boolEnables classic mode using vtastek shaders.
ONLY for openmw 0.47. Relevant shaders can be found in the OpenMW discord:
https://discord.com/channels/260439894298460160/718892786157617163/966468825321177148
output: Option<PathBuf>Output directory.
The plugin may be saved to any location, but its name will always be S3Lightfixes.omwaddon.
Accepts relative and absolute terms.
auto_enable: boolWhether to automatically enable the output plugin in openmw.cfg. Disabled by default. Typically lightfixes is ran under momw-configurator, making this param unnecessary for many users.
no_notifications: boolIf used, print to stdout instead of using native GUI dialogs. Not available on android.
debug: boolOutput debugging information during lightfixes generation Primarily displays output related to the openmw.cfg being used for generation
dry_run: Option<bool>Validate config and source plugins, print planned changes, but do not write files.
validate_config: Option<bool>Validate lightconfig.toml, CLI overrides, and regexes without generating a plugin.
generate_completion: Option<Shell>Generate shell completion script to stdout
generate_manpage: boolGenerate roff manpage to stdout
disable_flickering: Option<bool>Whether to disable flickering lights during lightfixes generation
disable_pulse: Option<bool>Whether to disable pulsing lights during lightfixes generation
disable_negative_lights: Option<bool>Whether to null negative lights during lightfixes generation
standard_hue: Option<f32>standard_saturation: Option<f32>standard_value: Option<f32>standard_radius: Option<f32>colored_hue: Option<f32>colored_saturation: Option<f32>colored_value: Option<f32>colored_radius: Option<f32>duration_mult: Option<f32>excluded_ids: Vec<String>excluded_plugins: Vec<String>light_overrides: Vec<(String, CustomLightData)>ambient_overrides: Vec<(String, CustomCellAmbient)>update_light_config: boolTrait Implementations
Sourceimpl Args for LightArgs
impl Args for LightArgs
Sourcefn group_id() -> Option<Id>
fn group_id() -> Option<Id>
ArgGroup::id][crate::ArgGroup::id] for this set of argumentsSourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command] so it can instantiate self via
[FromArgMatches::update_from_arg_matches_mut] Read moreSourceimpl FromArgMatches for LightArgs
impl FromArgMatches for LightArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl Parser for LightArgs
impl Parser for LightArgs
fn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>
fn try_update_from<I, T>(&mut self, itr: I) -> Result<(), Error>